==> ejc-assistrmat-api-3.0.0-20220914.090931-204-sources.jar: com/ejianc/business/outrmat/order/vo/OutRmatOrderDetailVO.java <==
package com.ejianc.business.outrmat.order.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 租赁订单明细
 * 
 * @author generator
 * 
 */
public class OutRmatOrderDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orderId; // 订单主键ID
    private Long materialId; // 物资主键
    private String materialSourceId; // 物资来源主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private Long unitId; // 单位id(计租单位)
    private String unitName; // 单位名称
    private String spec; // 规格型号
    private BigDecimal planNumsSum; // 计划数量
    private BigDecimal receiveNumsSum; // 接收数量
    private BigDecimal contractNumsSum; // 合同数量
    private BigDecimal contractSurplusNumsSum; // 合同剩余量
    private BigDecimal price; // 单价
    private BigDecimal mny; // 金额
    private String memo; // 备注
    private BigDecimal notDeliveredNumsSum; // 未送货数量
    private BigDecimal deliveredNumsSum; // 送货数量
    private Integer detailType; // 材料明细类型(1-价拨材料，2-租赁材料)
    private String rentCalculationType; // 计租方式：0-日租，1-月租，2-工程量租
    private Long unitMId; // 主单位(计量单位)
    private String unitMName; // 主单位名称
    private BigDecimal transScale; // 转换系数
    private BigDecimal deviationRate; // 偏差率
    private BigDecimal storeNumsSum; // 库存可用量

    public BigDecimal getStoreNumsSum() {
        return storeNumsSum;
    }

    public void setStoreNumsSum(BigDecimal storeNumsSum) {
        this.storeNumsSum = storeNumsSum;
    }

    public BigDecimal getDeviationRate() {
        return deviationRate;
    }

    public void setDeviationRate(BigDecimal deviationRate) {
        this.deviationRate = deviationRate;
    }

    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }

    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }

    public String getUnitMName() {
        return unitMName;
    }

    public void setUnitMName(String unitMName) {
        this.unitMName = unitMName;
    }

    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getPlanNumsSum() {
        return planNumsSum;
    }

    public void setPlanNumsSum(BigDecimal planNumsSum) {
        this.planNumsSum = planNumsSum;
    }
    public BigDecimal getReceiveNumsSum() {
        return receiveNumsSum;
    }

    public void setReceiveNumsSum(BigDecimal receiveNumsSum) {
        this.receiveNumsSum = receiveNumsSum;
    }
    public BigDecimal getContractNumsSum() {
        return contractNumsSum;
    }

    public void setContractNumsSum(BigDecimal contractNumsSum) {
        this.contractNumsSum = contractNumsSum;
    }
    public BigDecimal getContractSurplusNumsSum() {
        return contractSurplusNumsSum;
    }

    public void setContractSurplusNumsSum(BigDecimal contractSurplusNumsSum) {
        this.contractSurplusNumsSum = contractSurplusNumsSum;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getNotDeliveredNumsSum() {
        return notDeliveredNumsSum;
    }

    public void setNotDeliveredNumsSum(BigDecimal notDeliveredNumsSum) {
        this.notDeliveredNumsSum = notDeliveredNumsSum;
    }
    public Integer getDetailType() {
        return detailType;
    }

    public void setDetailType(Integer detailType) {
        this.detailType = detailType;
    }
    public String getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(String rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }

    public BigDecimal getDeliveredNumsSum() {
        return deliveredNumsSum;
    }

    public void setDeliveredNumsSum(BigDecimal deliveredNumsSum) {
        this.deliveredNumsSum = deliveredNumsSum;
    }
}

==> ejc-assistrmat-api-3.0.0-20221222.075652-338-sources.jar: com/ejianc/business/outrmat/order/vo/OutRmatOrderDetailVO.java <==
package com.ejianc.business.outrmat.order.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 租赁订单明细
 * 
 * @author generator
 * 
 */
public class OutRmatOrderDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orderId; // 订单主键ID
    private Long materialId; // 物资主键
    private String materialSourceId; // 物资来源主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private Long unitId; // 单位id(计租单位)
    private String unitName; // 单位名称
    private String spec; // 规格型号
    private BigDecimal planNumsSum; // 计划数量
    private BigDecimal receiveNumsSum; // 接收数量
    private BigDecimal contractNumsSum; // 合同数量
    private BigDecimal contractSurplusNumsSum; // 合同剩余量
    private BigDecimal price; // 单价
    private BigDecimal mny; // 金额
    private String memo; // 备注
    private BigDecimal notDeliveredNumsSum; // 未送货数量
    private BigDecimal deliveredNumsSum; // 送货数量
    private Integer detailType; // 材料明细类型(1-价拨材料，2-租赁材料)
    private String rentCalculationType; // 计租方式：0-日租，1-月租，2-工程量租
    private Long unitMId; // 主单位(计量单位)
    private String unitMName; // 主单位名称
    private BigDecimal transScale; // 转换系数
    private BigDecimal deviationRate; // 偏差率
    private BigDecimal storeNumsSum; // 库存可用量
    private BigDecimal storeNumM; // 库存可用计量数量

    public BigDecimal getStoreNumM() {
        return storeNumM;
    }

    public void setStoreNumM(BigDecimal storeNumM) {
        this.storeNumM = storeNumM;
    }

    public BigDecimal getStoreNumsSum() {
        return storeNumsSum;
    }

    public void setStoreNumsSum(BigDecimal storeNumsSum) {
        this.storeNumsSum = storeNumsSum;
    }

    public BigDecimal getDeviationRate() {
        return deviationRate;
    }

    public void setDeviationRate(BigDecimal deviationRate) {
        this.deviationRate = deviationRate;
    }

    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }

    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }

    public String getUnitMName() {
        return unitMName;
    }

    public void setUnitMName(String unitMName) {
        this.unitMName = unitMName;
    }

    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getPlanNumsSum() {
        return planNumsSum;
    }

    public void setPlanNumsSum(BigDecimal planNumsSum) {
        this.planNumsSum = planNumsSum;
    }
    public BigDecimal getReceiveNumsSum() {
        return receiveNumsSum;
    }

    public void setReceiveNumsSum(BigDecimal receiveNumsSum) {
        this.receiveNumsSum = receiveNumsSum;
    }
    public BigDecimal getContractNumsSum() {
        return contractNumsSum;
    }

    public void setContractNumsSum(BigDecimal contractNumsSum) {
        this.contractNumsSum = contractNumsSum;
    }
    public BigDecimal getContractSurplusNumsSum() {
        return contractSurplusNumsSum;
    }

    public void setContractSurplusNumsSum(BigDecimal contractSurplusNumsSum) {
        this.contractSurplusNumsSum = contractSurplusNumsSum;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getNotDeliveredNumsSum() {
        return notDeliveredNumsSum;
    }

    public void setNotDeliveredNumsSum(BigDecimal notDeliveredNumsSum) {
        this.notDeliveredNumsSum = notDeliveredNumsSum;
    }
    public Integer getDetailType() {
        return detailType;
    }

    public void setDetailType(Integer detailType) {
        this.detailType = detailType;
    }
    public String getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(String rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }

    public BigDecimal getDeliveredNumsSum() {
        return deliveredNumsSum;
    }

    public void setDeliveredNumsSum(BigDecimal deliveredNumsSum) {
        this.deliveredNumsSum = deliveredNumsSum;
    }
}
